]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - common.c
change GAME_ZYMOTIC default data dir to basezym
[xonotic/darkplaces.git] / common.c
index a8d0a9f43d262cfe40a7ee85db488d4e017751d8..561d404fb4982020df3b3cae8043fb92f72cb452 100644 (file)
--- a/common.c
+++ b/common.c
@@ -252,6 +252,12 @@ void MSG_WriteString (sizebuf_t *sb, const char *s)
                SZ_Write (sb, s, (int)strlen(s)+1);
 }
 
+void MSG_WriteUnterminatedString (sizebuf_t *sb, const char *s)
+{
+       if (s)
+               SZ_Write (sb, s, (int)strlen(s));
+}
+
 void MSG_WriteCoord13i (sizebuf_t *sb, float f)
 {
        if (f >= 0)
@@ -783,7 +789,6 @@ skipwhite:
                }
                com_token[len] = 0;
                *datapointer = data+1;
-               return true;
        }
        else
        {
@@ -800,8 +805,9 @@ skipwhite:
                }
                com_token[len] = 0;
                *datapointer = data;
-               return true;
        }
+
+       return true;
 }
 
 
@@ -938,7 +944,7 @@ static const gamemode_info_t gamemode_info [] =
 { "battlemech",                "-battlemech",  "Battlemech",                   "base",         NULL,                   "battlemech",   "battlemech" },
 // GAME_ZYMOTIC
 // COMMANDLINEOPTION: Game: -zymotic runs the singleplayer game Zymotic
-{ "zymotic",           "-zymotic",             "Zymotic",                              "data",         NULL,                   "zymotic",              "zymotic" },
+{ "zymotic",           "-zymotic",             "Zymotic",                              "basezym",              NULL,                   "zymotic",              "zymotic" },
 // GAME_FNIGGIUM
 // COMMANDLINEOPTION: Game: -fniggium runs the post apocalyptic melee RPG Fniggium
 { "fniggium",          "-fniggium",    "Fniggium",                             "data",         NULL,                   "fniggium",             "fniggium" },
@@ -956,16 +962,19 @@ static const gamemode_info_t gamemode_info [] =
 { "neoteric",          "-neoteric",    "Neoteric",                             "id1",          "neobase",              "neo",                  "darkplaces" },
 // GAME_OPENQUARTZ
 // COMMANDLINEOPTION: Game: -openquartz runs the game OpenQuartz, a standalone GPL replacement of the quake content
-{ "openquartz",                "-openquartz",  "OpenQuartz",                   "id1",          NULL,                   "openquartz",   "darkplaces"},
+{ "openquartz",                "-openquartz",  "OpenQuartz",                   "id1",          NULL,                   "openquartz",   "darkplaces" },
 // GAME_PRYDON
 // COMMANDLINEOPTION: Game: -prydon runs the topdown point and click action-RPG Prydon Gate
-{ "prydon",                    "-prydon",              "PrydonGate",                   "id1",          "prydon",               "prydon",               "darkplaces"},
+{ "prydon",                    "-prydon",              "PrydonGate",                   "id1",          "prydon",               "prydon",               "darkplaces" },
 // GAME_NETHERWORLD
-// COMMANDLINEOPTION: Game: -netherworld runs the game Netherworld: Dark Masters
-{ "netherworld",       "-netherworld", "Dark Masters",                 "id1",          "netherworld",  "nw",                   "darkplaces"},
+// COMMANDLINEOPTION: Game: -netherworld runs the game Netherworld: Dark Master
+{ "netherworld",       "-netherworld", "Netherworld: Dark Master",     "id1",          "netherworld",  "nw",                   "darkplaces" },
 // GAME_THEHUNTED
-// COMMANDLINEOPTION: Game: -netherworld runs the game The Hunted
-{ "thehunted",         "-thehunted",   "The Hunted",                   "thdata",       NULL,                   "th",                   "thehunted"},
+// COMMANDLINEOPTION: Game: -thehunted runs the game The Hunted
+{ "thehunted",         "-thehunted",   "The Hunted",                   "thdata",       NULL,                   "th",                   "thehunted" },
+// GAME_DEFEATINDETAIL2
+// COMMANDLINEOPTION: Game: -did2 runs the game Defeat In Detail 2
+{ "did2",                      "-did2",                "Defeat In Detail 2",   "data",         NULL,                   "did2_",                "did2" },
 };
 
 void COM_InitGameType (void)